-- Spline to NURBS Curve Converter
-- by Jarek Dukat
-- http://www.nautilus.com.pl/jarek
-- jarek@nautilus.com.pl

global crv_converted, crv_sel

-- Utility definition
utility convertspilne "Spline to NURBS Conv."
(
	pickbutton convspline "Pick Spline Shape" filter:validspline width:140 height:19

-- about labels
	label ab1 "Spline Shape" offset:[0,10]
	label ab2 "to NURBS Curve Converter 1.0"
	label ab3 "by Jarek Dukat" offset:[0,5]
	label ab4 "http://www.nautilus.com.pl/jarek"
	label ab5 "jarek@nautilus.com.pl"

-- picked NURBS curve handler
	on convspline picked node do
	(
		crv_converted = #()
		crv_sel = #()
		tmp = copy node
		converttosplineshape tmp
		nspl = tmp.numsplines
		delete tmp
		for i = 1 to nspl do doconvspline node i

		if crv_converted.count == 1 then
			txt = "Spline Shape \"" + node.name + "\" successfully converted to NURBS Curve \"" + crv_converted[1] + "\"."
		else
		(
			txt = "Spline Shape \"" + node.name + "\" successfully converted to multiple NURBS Curves:\n"
			for i = 1 to crv_converted.count do
				txt += (i as string) + ": \"" + crv_converted[i] + "\";\n"
		)
		messagebox txt title:"Convert Relults" beep:false
		select crv_sel
	)
)

-- verify if the picked object is a spline shape curve
fn validspline obj = (superclassof obj == shape) and ((ClassOf obj != cv_curve) and (ClassOf obj != point_curve))

fn doconvspline shp spl =
(
	cp = copy shp
	ncnm = if spl>9 then (spl as string) else ("0" + (spl as string))
	cp.name = (shp.name + " Converted " + ncnm)
	crv_converted[spl] = cp.name

	converttosplineshape cp
	num = cp.numsplines
	for n = 1 to (spl-1) do deletespline cp 1
	for n = (spl+1) to num do deletespline cp 2
	updateshape cp

	converttonurbscurve cp

	nset = getnurbsset cp #relational
	m = nset.numobjects
	if m > 1 do
	(
		tmp1 = (getobject nset 1).nurbsid
		tmp2 = (getobject nset 2).nurbsid
		joincurves cp tmp1 tmp2 0 flip1:true

		n = 3
		while (n <= m) do
		(
			tmp1 = (getobject nset n).nurbsid
			tmp_nset = getnurbsset cp #relational
			tmp2 = (getobject tmp_nset (tmp_nset.numobjects)).nurbsid
			joincurves cp tmp2 tmp1 0.0 flip1:true
			n += 1
		)
	)
	crv_sel[spl] = cp
)